@@ -1,4 +1,4 @@
-# Copyright 2001-2007, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,13 +10,13 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = "0.63";
+our $VERSION = "0.67";
 
 use DynaLoader ();
 our @ISA = "DynaLoader";
 
-use Devel::Cover::DB  0.63;
-use Devel::Cover::Inc 0.63;
+use Devel::Cover::DB  0.67;
+use Devel::Cover::Inc 0.67;
 
 use B qw( class ppname main_cv main_start main_root walksymtable OPf_KIDS );
 use B::Debug;
@@ -84,6 +84,7 @@ use vars '$File',                        # Last filename we saw.  (localised)
                                          # over conditions.  (localised)
          '%Files',                       # Whether we are interested in files.
                                          # Used in runops function.
+         '$Replace_ops',
          '$Silent';                      # Output nothing. Can be used anywhere.
 
 BEGIN
@@ -249,6 +250,8 @@ EOM
     POSIX::_exit(1);
 }
 
+$Replace_ops = 1;
+
 sub import
 {
     return if $Initialised;
@@ -256,7 +259,7 @@ sub import
     my $class = shift;
 
     my @o = (@_, split ",", $ENV{DEVEL_COVER_OPTIONS} || "");
-    # print STDERR __PACKAGE__, ": Parsing options from [@_]\n";
+    # print STDERR __PACKAGE__, ": Parsing options from [@o]\n";
 
     my $blib = -d "blib";
     @Inc     = () if "@o" =~ /-inc /;
@@ -265,24 +268,27 @@ sub import
     while (@o)
     {
         local $_ = shift @o;
-        /^-silent/    && do { $Silent    = shift @o; next };
-        /^-dir/       && do { $Dir       = shift @o; next };
-        /^-db/        && do { $DB        = shift @o; next };
-        /^-merge/     && do { $Merge     = shift @o; next };
-        /^-summary/   && do { $Summary   = shift @o; next };
-        /^-blib/      && do { $blib      = shift @o; next };
-        /^-subs_only/ && do { $Subs_only = shift @o; next };
-        /^-coverage/  &&
+        /^-silent/      && do { $Silent      = shift @o; next };
+        /^-dir/         && do { $Dir         = shift @o; next };
+        /^-db/          && do { $DB          = shift @o; next };
+        /^-merge/       && do { $Merge       = shift @o; next };
+        /^-summary/     && do { $Summary     = shift @o; next };
+        /^-blib/        && do { $blib        = shift @o; next };
+        /^-subs_only/   && do { $Subs_only   = shift @o; next };
+        /^-replace_ops/ && do { $Replace_ops = shift @o; next };
+        /^-coverage/    &&
             do { $Coverage{+shift @o} = 1 while @o && $o[0] !~ /^[-+]/; next };
-        /^[-+]ignore/ &&
+        /^[-+]ignore/   &&
             do { push @Ignore,   shift @o while @o && $o[0] !~ /^[-+]/; next };
-        /^[-+]inc/    &&
+        /^[-+]inc/      &&
             do { push @Inc,      shift @o while @o && $o[0] !~ /^[-+]/; next };
-        /^[-+]select/ &&
+        /^[-+]select/   &&
             do { push @Select,   shift @o while @o && $o[0] !~ /^[-+]/; next };
         warn __PACKAGE__ . ": Unknown option $_ ignored\n";
     }
 
+    bootstrap Devel::Cover $VERSION;
+
     if (defined $Dir)
     {
         # Die tainting.
@@ -298,9 +304,7 @@ sub import
 
     unless (-d $DB)
     {
-        # Nasty hack to keep 5.6.1 happy.
         mkdir $DB, 0700 or croak "Can't mkdir $DB: $!\n";
-        chmod 0700, $DB or croak "Can't chmod $DB: $!\n";
     }
     $DB = $1 if Cwd::abs_path($DB) =~ /(.*)/;
     Devel::Cover::DB->delete($DB) unless $Merge;
@@ -681,7 +685,6 @@ sub report
     unless (-d $DB)
     {
         mkdir $DB, 0700 or croak "Can't mkdir $DB: $!\n";
-        chmod 0700, $DB or croak "Can't chmod $DB: $!\n";
     }
     $DB .= "/$run";
 
@@ -953,6 +956,12 @@ sub deparse
                     my $newop   = $false->first;
                     my $newcond = $newop->first;
                     my $newtrue = $newcond->sibling;
+                    if ($newcond->name eq "lineseq")
+                    {
+                        # lineseq to ensure correct line numbers in elsif()
+                        # Bug #37302 fixed by change #33710.
+                        $newcond = $newcond->first->sibling;
+                    }
                     # last in chain is OP_AND => no else
                     $false      = $newtrue->sibling;
                     { local $Collect; $newcond = $self->deparse($newcond, 1) }
@@ -1158,8 +1167,6 @@ sub get_cover
     $de
 }
 
-bootstrap Devel::Cover $VERSION;
-
 1
 
 __END__
@@ -1170,12 +1177,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 SYNOPSIS
 
- perl -MDevel::Cover yourprog args
- cover
-
- perl -MDevel::Cover=-db,cover_db,-coverage,statement,time yourprog args
-
-To test an uninstalled module:
+To get coverage for an uninstalled module:
 
  cover -test
 
@@ -1185,7 +1187,8 @@ or
  HARNESS_PERL_SWITCHES=-MDevel::Cover make test
  cover
 
-To test an uninstalled module which uses Module::Build (0.26 or later):
+To get coverage for an uninstalled module which uses Module::Build (0.26 or
+later):
 
  ./Build testcover
 
@@ -1193,12 +1196,19 @@ If the module does not use the t/*.t framework:
 
  PERL5OPT=-MDevel::Cover make test
 
+If you want to get coverage for a program:
+
+ perl -MDevel::Cover yourprog args
+ cover
+
+ perl -MDevel::Cover=-db,cover_db,-coverage,statement,time yourprog args
+
 =head1 DESCRIPTION
 
 This module provides code coverage metrics for Perl. Code coverage
 metrics describe how thoroughly tests exercise code. By using
-Devel::Cover you can find areas of code not exercised by your tests
-and find out which tests to create to increase coverage. Code coverage
+Devel::Cover you can discover areas of code not exercised by your tests
+and determine which tests to create to increase coverage. Code coverage
 can be considered as an indirect measure of quality.
 
 I consider this software to have an alpha status.  By that I mean that I
@@ -1214,6 +1224,10 @@ Code coverage data are collected using a pluggable runops function which
 counts how many times each op is executed.  These data are then mapped
 back to reality using the B compiler modules.  There is also a statement
 profiling facility which needs a better backend to be really useful.
+This release also includes an experimental mode which replaces ops
+instead of using a pluggable runops function.  This provides a nice
+speed increase, but needs better testing before it becomes the default.
+You probably don't care about any of this.
 
 The F<cover> program can be used to generate coverage reports.
 
@@ -1288,8 +1302,9 @@ if the tests fail and you would like nice output telling you why.
  -merge val          - Merge databases, for multiple test benches (default on).
  -select RE          - Set REs of files to select (default none).
  +select RE          - Append to REs of files to select.
- -silent val         - Don't print informational messages (default off)
- -subs_only val      - Only cover code in subroutine bodies (default off)
+ -silent val         - Don't print informational messages (default off).
+ -subs_only val      - Only cover code in subroutine bodies (default off).
+ -replace_ops val    - Use op replacing rather than runops (default on).
  -summary val        - Print summary information iff val is true (default on).
 
 =head2 More on Coverage Options
@@ -1421,17 +1436,17 @@ CV.  Hints, tips or patches to resolve this will be gladly accepted.
 
 =head1 BUGS
 
-Did I mention that this is alpha code?
+Almost certainly.
 
 See the BUGS file.  And the TODO file.
 
 =head1 VERSION
 
-Version 0.63 - 16th November 2007
+Version 0.67 - 8th May 2010
 
 =head1 LICENCE
 
-Copyright 2001-2007, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
