@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.64;
-use Devel::Cover::Truth_Table 0.64;
+use Devel::Cover::DB 0.67;
+use Devel::Cover::Truth_Table 0.67;
 
-our $VERSION = "0.64";
+our $VERSION = "0.67";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -261,8 +261,8 @@ sub print_html_header {
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version 0.64
-Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
+This file was generated by Devel::Cover Version 0.67
+Devel::Cover is copyright 2001-2010, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -288,7 +288,7 @@ sub print_summary {
     my $fh       = shift;
     my $title    = shift;
     my $file     = shift;
-    my $percent  = sprintf("%.1f", shift @_);
+    my $percent  = sprintf("%.1f", shift @_ || 0);
     my $error    = shift;
     my $db       = shift;
     my $class    = pclass($percent, $error);
@@ -776,11 +776,11 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.64 - 10th April 2008
+Version 0.67 - 8th May 2010
 
 =head1 LICENCE
 
-Copyright 2001-2008, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
 
 This software is free. It is licensed under the same terms as Perl itself.
 
